import md5 from 'js-md5'
import dayjs from 'dayjs'
import * as qiniu from 'qiniu-js'

/**
 * md5 加密
 * @param val string
 * @returns strng
 */
export const fnMd5 = (val: string) => md5(val)

/**
 * 判断对象是否为空
 * @param obj Object
 * @returns boolean
 */
export const isEmptyObject = (obj: object) => Object.keys(obj).length > 0

/**
 * 时间的处理
 * @param date new Date
 * @returns string
 */
export const dayJs = (date: Date | string) => dayjs(date)

/**
 *
 * @param menuList 菜单列表
 * @param result 输出得结果
 * @param parent 子菜单
 * @returns object
 */
export const getAllBreadcrumbList = (menuList: any, result: { [key: string]: any } = {}, parent = []) => {
  for (const item of menuList) {
    result[item.T_permission.trim()] = [...parent, item]
    if (item.Children) getAllBreadcrumbList(item.Children, result, result[item.T_permission])
  }
  return result
}

// {
//     path: '/home',
//     name: 'Home',
//     meta: {
//       icon: 'HomeFilled',
//       title: '首页',
//       isKeepAlive: true
//     }
//   },

export const hanlderMenuList = (menuList: any) => {
  // console.log(menuList)
}
/**
 * 分钟转小时
 * @param time
 */
export const getFormatDuration = (time: number) => {
  console.log(time)
  let hour = 0
  let minute = 0
  let result = ''
  if (time >= 60) {
    hour = time / 60
    minute = time % 60
  } else {
    result = '' + time + '分'
  }
  if (minute > 0) {
    result = '' + parseInt(minute + '') + '分' + result
  }
  if (hour > 0) {
    result = '' + parseInt(hour + '') + '小时' + result
  }
  return result
}

/**
 *
 * @param {*} file 上传的文件
 * @param {*} token 上传需要的token
 */
export const qiniuUpLoadFun = (file: any, token: any) => {
  //七牛上传方法
  return new Promise(function (resolve) {
    let timestamp = new Date().valueOf()
    let params = {
      file: file, //要上传的文件
      key: 'paper_file/' + timestamp + file.name, //自定义文件地址
      token: token,
      config: {
        useCdnDomain: false,
        // region: undefined,
        region: qiniu.region.z2,
        domin: 'https://qiniu.region.z2',
        chunkSize: 1000
      },
      putExtra: {
        fname: file.name,
        params: {},
        mimeType: [] || null
      }
    }
    console.log('domin')
    resolve(params)
  })
}
export function upLoadQiniu(params: any) {
  let observable = qiniu.upload(params.file, params.key, params.token, params.putExtra, params.config)
  let observer = {
    next(res: any) {
      // console.log(res);
      console.log('上传中', res)
    },
    error(err: any) {
      console.log(err)
    },
    complete(res: any) {
      // let url = 'http://xxxxxx.cn/' + res.key
      // layer.close(loading) //关闭loading效果
      console.log(res)
      // resolve(url)
    }
  }
  observable.subscribe(observer)
}
